%global pypi_name trimesh

Name:           python-%{pypi_name}
Version:        2.35.24
Release:        1%{?dist}
Summary:        Import, export, process, analyze and view triangular meshes

License:        MIT
URL:            https://trimsh.org

Source0:        https://github.com/mikedh/trimesh/archive/%{version}/%{pypi_name}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3dist(lxml)
BuildRequires:  python3dist(msgpack-python)
BuildRequires:  python3dist(networkx)
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(requests)
BuildRequires:  python3dist(rtree)
BuildRequires:  python3dist(scipy)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(shapely)
BuildRequires:  python3dist(svg.path)
BuildRequires:  python3dist(sympy)

# https://github.com/cnr-isti-vclab/meshlab/issues/237
#BuildRequires:  /usr/bin/xvfb-run
#BuildRequires:  /usr/bin/meshlabserver

%?python_enable_dependency_generator

%description
Trimesh is a pure Python library for loading and using triangular meshes with
an emphasis on watertight meshes. The goal of the library is to provide
a fully featured and well tested Trimesh object which allows for easy
manipulation and analysis, in the style of the Polygon object in the Shapely
library.


%package -n     python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}

Recommends:     python3-%{pypi_name}-easy = %{version}-%{release}
Suggests:       python3-%{pypi_name}-all = %{version}-%{release}

# for trimesh.boolean
Recommends:     openscad
Recommends:     blender

%description -n python3-%{pypi_name}
Trimesh is a pure Python library for loading and using triangular meshes with
an emphasis on watertight meshes. The goal of the library is to provide
a fully featured and well tested Trimesh object which allows for easy
manipulation and analysis, in the style of the Polygon object in the Shapely
library.


%package -n     python3-%{pypi_name}-easy
Summary:        Easy dependencies for %{pypi_name}
%{?python_provide:%python_provide python3-%{pypi_name}-easy}

Requires:       python3-%{pypi_name} = %{version}-%{release}

Requires:       python3dist(lxml)
Requires:       python3dist(pyglet)
Requires:       python3dist(shapely)
Requires:       python3dist(rtree)
Requires:       python3dist(svg.path)
Requires:       python3dist(sympy)
Requires:       python3dist(msgpack)
Requires:       python3dist(pillow)
Requires:       python3dist(requests)
Requires:       python3dist(colorlog)

# not yet packaged
Recommends:     python3dist(xxhash)

%description -n python3-%{pypi_name}-easy
Extra dependencies for trimesh[easy].


%package -n     python3-%{pypi_name}-all
Summary:        All dependencies for %{pypi_name}
%{?python_provide:%python_provide python3-%{pypi_name}-all}

Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-%{pypi_name}-easy = %{version}-%{release}

Requires:       python3dist(setuptools)

# not yet packaged
Recommends:     python3dist(python-fcl)
# triangle has nonfree dependencies
#Never:         python3dist(triangle)

%description -n python3-%{pypi_name}-all
Extra dependencies for trimesh[all].


%prep
%autosetup -n %{pypi_name}-%{version} -p1


%build
%py3_build


%install
%py3_install


%check
# test_export doesn't work in mock:
# https://github.com/cnr-isti-vclab/meshlab/issues/237
# test_remote requires internet connection
# https://github.com/mikedh/trimesh/issues/247
%{__python3} -m pytest -v -k "not test_export and not test_remote"


%files -n python3-%{pypi_name}
%license LICENSE.md
%doc README.md
%{python3_sitelib}/%{pypi_name}
%{python3_sitelib}/%{pypi_name}-%{version}-py?.?.egg-info/

%files -n python3-%{pypi_name}-easy
# empty

%files -n python3-%{pypi_name}-all
# empty


%changelog
* Fri Nov 09 2018 Miro Hrončok <mhroncok@redhat.com> - 2.35.24-1
- Update to 2.35.24 (#1648477)

* Mon Sep 03 2018 Miro Hrončok <mhroncok@redhat.com> - 2.33.12-1
- Update to 2.33.12

* Mon Sep 03 2018 Miro Hrončok <mhroncok@redhat.com> - 2.33.11-1
- Initial package
